import { BaseResponse } from "@/shared/model-components";
import {tenementSearchChoice, tenementSearchChoiceByName} from "@q/charge";
import { useQuery } from "@tanstack/react-query";
import { isCorrectResult } from "@u/asyncs";
import { Select } from "antd";
import { equals } from "ramda";
import { useState } from "react";
import { useDebounce } from "react-use";
import 'twin.macro'

interface P {
    parkId?: string,
    disabled?: boolean
    allowClear?: boolean,
    placeholder?: string,
    onChange?: (e: any) => void,
    api?: (keyword: string) => Promise<BaseResponse & { tenements: { fullName: string; id: string; park: string; shortName: string; parkName: string }[] }>
}


const CompanyNoPark = (props: P) => {
    const [searchTenement, setSearchTenement] = useState('');
    const [searchTenementTemp, setSearchTenementTemp] = useState('');

    // 商户列表
    const { data: tenements, status: tenementStatus } = useQuery(
        ['tenements-getSelectList', searchTenement],
        () => props.api ? props.api(searchTenement) : props.parkId ? tenementSearchChoice(props.parkId, searchTenement) : tenementSearchChoiceByName(searchTenement),
        { enabled: !!searchTenement, select: res => (isCorrectResult(res) ? res.tenements : []) }
    )


    useDebounce(() => setSearchTenement(searchTenementTemp), 800, [searchTenementTemp]);
    return (
            <Select
                tw="w-full"
                showSearch
                disabled={props.disabled}
                allowClear={props.allowClear}
                // showArrow={false}
                filterOption={false}
                notFoundContent={null}
                onChange={e => props.onChange && props.onChange(e)}
                onSearch={setSearchTenementTemp}
                defaultActiveFirstOption={false}
                placeholder={props.placeholder || "请输入商户全称检索"}
                loading={equals(tenementStatus, 'loading')}
                options={(tenements || []).map(d => ({ value: d.id, label: `${d.parkName ?( d.parkName || '') + ' - ' : ""} ${d.fullName}` }))}
                dropdownStyle={{minWidth: "250px", width: 'auto'}}
            />
    )
}

export default CompanyNoPark;
