// @ts-ignore
import {ProTable} from '@ant-design/pro-components';
import React, {ReactNode} from "react";
import "twin.macro"
import {ExpandableConfig} from "antd/lib/table/interface";

interface Props {
  columns: any[],
  dataSource: any[],
  localStorageKey: string,
  rowKey: (value: any) => string,
  rowClassName?: (record: any, index: number) => string,
  loading: boolean,
  pagination?:false | {
    total: number,
    current: number,
    onChange: (value: number) => void,
  },
  scroll?: {
    x?: number|string,
    y?: number|string
  }
  toolbarRender?: ReactNode[],
  toolbar?: ReactNode,
  expandable?: ExpandableConfig<any>
  rowSelection?:any,
  size?: string,
  customPagination?: boolean,
  footer?: ReactNode,
  // search?: ReactNode
}

export default function (props: Props) {
  const {
    columns = [],
    dataSource = [],
    loading,
    rowKey,
    pagination= { total: 0,  current: 1, onChange: () => {}, showSizeChanger: false },
    scroll,
    localStorageKey,
    toolbarRender,
    toolbar,
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    size,
    customPagination,
    footer,
    ...other
    // search
  } = props
  return (
    <>
      <style>
        {
          `
            .ant-table-fixed-left table,
            .ant-table-fixed-right table {
              width: min-content;
            }
            .ant-pro-table-list-toolbar-left, .ant-pro-table-list-toolbar-title {
              flex: 1 !important;
            }
            .ant-pro-table-list-toolbar-right {
              flex: 0 !important;
              flex-wrap: nowrap;
            }
            
            .ant-pro-table-list-toolbar-container {
              padding-top: 0;
            }
          `
        }
      </style>
      <ProTable
        columns={columns}
        columnsState={{
          persistenceKey: localStorageKey,
          persistenceType: 'sessionStorage',
        }}
        tableExtraRender={null}
        cardProps={false}
        search={false}
        rowKey={rowKey}
        tableAlertRender={false}
        loading={loading}
        columnEmptyText={""}
        options={{
          setting: true,
          reload: false,
          density: false,
        }}
        scroll={scroll}
        dataSource={dataSource}
        pagination={customPagination ? false : (pagination === false ? pagination : {
          size: "default",
          pageSize: 20,
          showSizeChanger: false,
          ...pagination
        })}
        toolBarRender={() => toolbarRender}
        toolbar={{
          title: <div tw={"w-full"}> {toolbar} </div>
        }}
        {...other}
      />
      {footer}
    </>

  )
}
