// 用于生成一个根据关键字搜索商户的输入选择框
import { BaseResponse } from "@/shared/model-components";
import { tenementSearchChoice } from "@q/charge";
import { useQuery } from "@tanstack/react-query";
import { isCorrectResult } from "@u/asyncs";
import { Select } from "antd";
import { useState } from "react";
import { useDebounce } from "react-use";
import 'twin.macro'

interface P {
    parkId?: string,
    tenement?: string,
    disabled?: boolean
    allowClear?: boolean
    placeholder?: string
    onChange?: (e) => void,
    valueKey?: string,
    labelKey?: string,
    api?: (parkId: string, tenement: string) => Promise<BaseResponse & {
        tenements: {
            fullName: string;
            id: string;
            park: string;
            shortName: string;
        }[];
    }>
}


const Company = (props: P) => {
    const { parkId } = props;
    const [searchTenement, setSearchTenement] = useState('');
    const [searchTenementTemp, setSearchTenementTemp] = useState('');

    const request = props.api ? props.api :  tenementSearchChoice
    // 商户列表
    const { data: tenements } = useQuery(
        ['tenements-choice', parkId, searchTenement],
        () => request(parkId, searchTenement),
        { enabled: !!searchTenement && !!parkId, select: res => (isCorrectResult(res) ? res.tenements : []) }
    );
    useDebounce(() => setSearchTenement(searchTenementTemp), 800, [searchTenementTemp]);
    return (
        <Select
            tw="w-full"
            showSearch
            allowClear={props.allowClear}
            filterOption={false}
            notFoundContent={null}
            onChange={e => { props.onChange && props.onChange(e) }}
            onSearch={setSearchTenementTemp}
            defaultActiveFirstOption={false}
            value={props.tenement}
            placeholder={props.placeholder || "请输入商户名称检索"}
            options={(tenements || []).map(d => ({ value: props.valueKey ? d[props.valueKey]: d.id, label: props.labelKey ? d[props.labelKey] : d.fullName }))}
        />
    )
}

export default Company;
