//@ts-nocheck
import { CentralSpin } from '@c/ui/CentralSpin';
import { lazyLoad } from '@u/lazyload';
import { prop } from 'ramda';
import { FC, Suspense } from 'react';

/**
 * 为异步加载组件套上一层统一的加载指示。
 * @param componentName 要导入的组件名称
 * @param loader 要导入的组件所在文件
 * @returns 在外部套上一层加载指示的异步加载组件。
 */
export const suspense = (componentName: string, loader: () => Promise): FC<any> => {
  const Component = prop(componentName, lazyLoad(loader));
  return props => (
    <Suspense fallback={<CentralSpin />}>
      <Component {...props} />
    </Suspense>
  );
};

/**
 * 异步加载并导入指定的组件，将直接解析出指定组件，不做其他任何处理。
 * @param componentName 要导入的组件名称
 * @param loader
 * @returns 导入的指定组件
 */
export const asyncLoad = (componentName: string, loader: () => Promise): FC<any> => {
  const Component = prop(componentName, lazyLoad(loader));
  return props => <Component {...props} />;
};
