// 用于生成一个根据关键字搜索商户的输入选择框
import { meter04List } from "@q/park";

import { useQuery } from "@tanstack/react-query";
import { isCorrectResult } from "@u/asyncs";
import { Select } from "antd";
import { equals } from "ramda";
import { useState } from "react";
import { useDebounce } from "react-use";
import 'twin.macro'

interface P {
    parkId?: string,
    Meter?: string,
    disabled?: boolean
    allowClear?: boolean
    placeholder?: string
    onChange?: (e) => void,
    valueKey?: string,
    labelKey?: string,
}


const Meter = (props: P) => {
    const { parkId } = props;
    const [searchMeter, setSearchMeter] = useState('');
    const [searchMeterTemp, setSearchMeterTemp] = useState('');
    // 商户列表
    const { data: Meters, status: MeterStatus } = useQuery(
        ['meter-select-list', parkId, searchMeter],
        () => { return meter04List(parkId, 1, searchMeter, undefined)},
        { enabled: !!searchMeter, select: res => (isCorrectResult(res) ? res.meters : []) }
    );

    useDebounce(() => setSearchMeter(searchMeterTemp), 800, [searchMeterTemp]);
    return (
        <Select
            tw="w-full"
            showSearch
            allowClear={props.allowClear}
            filterOption={false}
            notFoundContent={null}
            onChange={e => { props.onChange && props.onChange(e) }}
            onSearch={setSearchMeterTemp}
            defaultActiveFirstOption={false}
            value={props.Meter}
            placeholder={props.placeholder || "请输入表号检索"}
            loading={equals(MeterStatus, 'loading')}
            options={(Meters || []).map(d => ({ value: props.valueKey ? d[props.valueKey]: d.meterNo, label: props.labelKey ? d[props.labelKey] : d.meterNo }))}
        />
    )
}

export default Meter;
