import { isNil } from 'ramda';
import tw, { styled } from 'twin.macro';
import { Panel } from './Panel';

/**
 * 用于定义动态缩放面板的组件属性。
 */
export interface DynamicStretchPanelProps {
  /**
   * 确定面板当前是否处于展开状态。
   */
  extended: boolean;

  /**
   * 确定面板的最小宽度，使用CSS百分比或者具体像素大小描述。
   */
  minWidth: string;
}

/**
 * 动态缩放面板组件。
 */
export const DynamicStretchPanel = styled(Panel)(({ extended, minWidth }: DynamicStretchPanelProps) => [
  tw`flex flex-col justify-start items-start space-y-1 p-2`,
  !isNil(minWidth) && !extended && `max-width: ${minWidth}`,
  extended && tw`flex-grow`
]);

/**
 * 动态缩放面板中使用的垂直布局。
 */
export const VerticalLayout = tw.div`flex flex-col justify-start items-stretch w-full h-full`;
/**
 * 动态缩放面板中使用的水平布局。
 */
export const HorizontalLayout = tw.div`flex flex-row justify-start items-stretch w-full h-full`;
/**
 * 动态缩放面板中使用的头部信息条。
 */
export const HeadLine = tw.div`flex flex-row justify-start items-center space-x-1`;
