//@ts-nocheck
import { gte } from 'ramda';
import { FC } from 'react';
import tw, { styled } from 'twin.macro';

const WeakIndicator = styled.div(({ enabled }) => [
  tw`flex-grow h-2`,
  enabled ? tw`bg-red-6` : tw`bg-gray-4`
]);
const MediumIndicator = styled.div(({ enabled }) => [
  tw`flex-grow h-2`,
  enabled ? tw`bg-yellow-6` : tw`bg-gray-4`
]);
const StrongIndicator = styled.div(({ enabled }) => [
  tw`flex-grow h-2`,
  enabled ? tw`bg-green-6` : tw`bg-gray-4`
]);

interface StrengthGadgetProps {
  /**
   * 当前要展示的强度数值。
   */
  strength: number;
}

export const StrengthGadget: FC<StrengthGadgetProps> = ({ strength }) => {
  return (
    <div tw="w-full pb-1 flex flex-col justify-start items-center">
      <div tw="w-full flex flex-row justify-between items-center space-x-0.5">
        <WeakIndicator enabled={gte(strength, 0)} />
        <MediumIndicator enabled={gte(strength, 1)} />
        <MediumIndicator enabled={gte(strength, 2)} />
        <StrongIndicator enabled={gte(strength, 3)} />
      </div>
      <div tw="w-full flex flex-row justify-between items-center text-xs text-gray-6">
        <div tw="text-left flex-grow">弱</div>
        <div tw="text-center flex-grow">密码强度</div>
        <div tw="text-right flex-grow">强</div>
      </div>
    </div>
  );
};
