/**
 * 加入了用于支持`instanceof`操作符的表示异常的基类。
 *
 * ! 所有用于表示各种异常的自定义异常类都必须继承自本类，不能直接继承`Error`类。
 */
export default class BaseError extends Error {
  constructor(message: string) {
    super(message);

    // ! 以下这一段是一套继承Error类的时候的固定用法，用以支持instanceof操作符，所有继承Error类代表异常的异常类都必须原样复制。
    this.name = new.target.name;
    if (typeof (Error as any).captureStackTrace === 'function') {
      (Error as any).captureStackTrace(this, new.target);
    }
    if (typeof Object.setPrototypeOf === 'function') {
      Object.setPrototypeOf(this, new.target.prototype);
    } else {
      (this as any).__proto__ = new.target.prototype;
    }
  }
}
