import { useSessionStore } from '@st/session_store';
import { notNil } from '@u/funcs';
import { App } from 'antd';
import { AxiosError } from 'axios';
import { equals } from 'ramda';
import { useNavigate } from 'react-router-dom';

/**
 * 用于提供对异步请求返回的错误结果的判断，只响应403错误，当出现403错误的时候，
 * 会直接将用户重定向到登录页面。
 *
 * @returns 返回一个判断函数check()，用于判断给定的错误参数是否是403错误，如果是403错误就执行重定向。
 */
export function useAnswer403Forbidden() {
  const { message } = App.useApp();
  const logout = useSessionStore.use.logout();

  const navigate = useNavigate();

  function checkError(error: AxiosError) {
    if (notNil(error) && error.isAxiosError) {
      if (equals(error.response.status, 403)) {
        // 这里做错误提示，主要用于提示用户不具有操作权限，并且将会自动结束用户会话。
        void message.error('你当前会话没有访问指定内容的权限，你的会话已被系统自动结束。', 2.5);
        logout();
        navigate('/login');
      }
    }
  }

  return { check: checkError };
}
