import { norNilOrEmpty } from '@u/funcs';
import dayjs from 'dayjs';
import { not } from 'ramda';
import { useExpiresAt, useToken } from './useSession';

/**
 * 判断当前用户是否已经通过了认证，处于登录状态，但不保证当前的会话依旧是有效的。
 * @returns 当前用户是否具有可用的会话令牌，即通过登录的状态。
 */
export function useIsLoggedIn(): boolean {
  const [token] = useToken();
  return norNilOrEmpty(token);
}

/**
 * 判断当前用户的会话是否已经过期。
 * @returns 当前用户的会话是否无效或者已经过期。
 */
export function useIsSessionExpired(): boolean {
  const [expiresAt] = useExpiresAt();
  return expiresAt.isBefore(dayjs());
}

/**
 * 判断用户是否已经经过了认证，处于登录状态
 * @returns 当前是否处于已经登录的状态
 */
export function useAuthenticated() {
  const isLoggedIn = useIsLoggedIn();
  const isExpired = useIsSessionExpired();

  return isLoggedIn && not(isExpired);
}
