import { MapFactory, SyncCallback, SyncObjectCallback } from '@/shared/foundation';
import { isNilOrEmpty, notNil } from '@u/funcs';
import { equals } from 'ramda';
import { useCallback } from 'react';

type LocalStorageOperates<T> = [T, SyncObjectCallback<T>, SyncCallback];
type useLocalStorageOption<T> = {
  raw?: boolean;
  serializer?: MapFactory<string, T>;
  deserializer?: MapFactory<T, string>;
};

/**
 * 重新定义的实时操作单一LocalStorage键的Hook。
 * @returns 按照顺序返回给定键的值、设置新值方法和删除值的方法。
 */
export function useLocalStorage<T>(
  key: string,
  defaultValue?: T,
  option?: useLocalStorageOption<T>
): LocalStorageOperates<T> {
  const rawValue = localStorage.getItem(key);
  const value = isNilOrEmpty(rawValue)
    ? defaultValue
    : equals(option?.raw ?? false, true)
    ? //@ts-ignore
      (rawValue as T)
    : notNil(option?.deserializer)
    ? option.deserializer(rawValue)
    : (JSON.parse(rawValue) as T);
  const setValue = useCallback((newValue: T) => {
    if (equals(option?.raw ?? false, true)) {
      //@ts-ignore
      localStorage.setItem(key, newValue);
    } else {
      const serialiedValue = notNil(option?.serializer)
        ? option.serializer(newValue)
        : JSON.stringify(newValue);
      //@ts-ignore
      localStorage.setItem(key, serialiedValue);
    }
  }, []);
  const removeStorage = useCallback(() => localStorage.removeItem(key), []);
  //@ts-ignore
  return [value, setValue, removeStorage];
}
