//@ts-nocheck
import { notNil } from '@u/funcs';
import { clone, defaultTo, is, isNil, mergeLeft } from 'ramda';
import { useLocation } from 'react-router-dom';

/**
 * 从React Router传递的location的State属性中获取指定的内容。
 * 会根据指定的默认值类型自动处理所取得的值。如果不给定默认值，则会按照获取到的值类型处理。
 * @param extractor 用于从路由State中获取或者计算获取指定形式的值的函数。
 * @param defaultValue 在指定内容不存在的时候所要使用的默认值。
 * @returns 路由State中所需要的内容。
 */
export function useLocationState<T, R = T>(extractor?: (T) => R, defaultValue?: R): R {
  const location = useLocation();
  const state = location.state as T;
  const extracted = notNil(extractor) && is(Function, extractor) ? extractor(state) : clone(state);

  return isNil(defaultValue)
    ? extracted
    : is(Object, defaultValue)
    ? mergeLeft(extracted, defaultValue)
    : defaultTo(defaultValue, extracted);
}
