import qs from 'qs';

import {
    BatchMeterResult,
    BatchModeForm,
    BatchParamsForm,
    BatchSwitchForm,
  BatchTroubleForm,
  BatchWarningForm,
  BindCardForm,
  BindProtocolForm,
  CardForm,
  CardListItem,
  CardListQuery,
  ChangeMeterEnabledForm,
  FactoryForm,
  FactoryListItem,
  FactoryListQuery,
  MeterOperateListItem,
  MeterOperateListQuery,
  MeterSettingForm,
  MeterSettingListItem,
  MeterSettingListQuery,
  NestedMeterForm,
  NestedMeterListItem,
  ProtocolForm,
  ProtocolListItem,
  ProtocolListQuery
} from '@/shared/equipment';
import type {
  BaseResponse,
  Pageable
} from '@/shared/model-components';
import { UploadExcelError } from '@/shared/model-park';
import { ajaxEngine } from '@q/axios_instance';
import { downloadFile } from '@q/common';
import { unwrap } from '@u/asyncs';
import { Key } from 'react';

/**
 * 获取卡列表
 * @param query CardListQuery
 */
export async function getCardList(query: CardListQuery): Promise<BaseResponse & Pageable & { data: CardListItem[], amount: number }> {
    const response = await ajaxEngine().get(`/equipment/getCardList?${qs.stringify(query)}`, {});
    return unwrap(response);
}

/**
 * 创建卡
 * @param data CardForm
 */
export async function createCard(data: CardForm): Promise<BaseResponse> {
    const response = await ajaxEngine().post(`/equipment/createCard`, data);
    return unwrap(response);
}

/**
 * 修改卡
 * @param data CardForm
 * @param id string
 */
export async function updateCard(data: CardForm, id: string): Promise<BaseResponse> {
    const response = await ajaxEngine().put(`/equipment/updateCard/${id}`, data);
    return unwrap(response);
}

/**
 * 删除卡
 * @param id string
 */
export async function deleteCard(id: string): Promise<BaseResponse> {
    const response = await ajaxEngine().delete(`/equipment/deleteCard/${id}`);
    return unwrap(response);
}

/**
 * 上传卡
 * @param park 园区id
 * @param file 文件对象
 * @param onProgress 进度监听
 */
export async function uploadCard(
    park: string,
    file: File,
    onProgress?: (percent: number) => void
): Promise<BaseResponse & { errors: UploadExcelError[] | null }> {
    const response = await ajaxEngine().postForm(
        `/equipment/uploadCard/${park}`,
        { data: file },
        { onUploadProgress: (e: ProgressEvent) => onProgress?.(e.loaded / e.total) }
    );
    return unwrap(response);
}
/**
 * 导出卡模板
 */
export async function downloadCardTemplate() {
    return downloadFile(`/equipment/exportCardTemplate`);
}
/**
 * 导出卡数据
 */
export async function downloadCard(park: string, query: any) {
    return downloadFile(`/equipment/exportCard/${park}?${qs.stringify(query)}`);
}
/**
 * 获取通讯协议列表
 * @param query CardListQuery
 */
export async function getProtocolList(query: ProtocolListQuery): Promise<BaseResponse & Pageable & { data: ProtocolListItem[] }> {
    const response = await ajaxEngine().get(`/equipment/getProtocolList?${qs.stringify(query)}`, {});
    return unwrap(response);
}
/**
 * 导出通讯协议模板
 */
export async function downloadProtocolTemplate() {
    return downloadFile(`/equipment/exportProtocolTemplate`);
}
/**
 * 导出通讯协议数据
 */
export async function downloadProtocol(park: string, query: any) {
    return downloadFile(`/equipment/exportCard/${park}?${qs.stringify(query)}`);
}
/**
 * 上传通讯协议
 * @param park 园区id
 * @param file 文件对象
 * @param onProgress 进度监听
 */
export async function uploadProtocol(
    park: string,
    file: File,
    onProgress?: (percent: number) => void
): Promise<BaseResponse & { errors: UploadExcelError[] | null }> {
    const response = await ajaxEngine().postForm(
        `/equipment/uploadCard/${park}`,
        { data: file },
        { onUploadProgress: (e: ProgressEvent) => onProgress?.(e.loaded / e.total) }
    );
    return unwrap(response);
}
/**
 * 创建通讯协议
 * @param data CardForm
 */
export async function createProtocol(data: ProtocolForm): Promise<BaseResponse> {
    const response = await ajaxEngine().post(`/equipment/createProtocol`, data);
    return unwrap(response);
}

/**
 * 修改通讯协议
 * @param data CardForm
 * @param id string
 */
export async function updateProtocol(data: ProtocolForm, id: string): Promise<BaseResponse> {
    const response = await ajaxEngine().put(`/equipment/updateProtocol/${id}`, data);
    return unwrap(response);
}

/**
 * 删除通讯协议
 * @param id string
 */
export async function deleteProtocol(id: string): Promise<BaseResponse> {
    const response = await ajaxEngine().delete(`/equipment/deleteProtocol/${id}`);
    return unwrap(response);
}

/**
 * 获取厂家列表
 * @param query FactoryListQuery
 */
export async function getFactoryList(query: FactoryListQuery): Promise<BaseResponse & Pageable & { data: FactoryListItem[] }> {
    const response = await ajaxEngine().get(`/equipment/getManufacturersList?${qs.stringify(query)}`, {});
    return unwrap(response);
}

/**
 * 创建厂家
 * @param data CardForm
 */
export async function createFactory(data: FactoryForm): Promise<BaseResponse> {
    const response = await ajaxEngine().post(`/equipment/createManufacturers`, data);
    return unwrap(response);
}
/**
 * 修改厂家
 * @param data CardForm
 * @param id string
 */
export async function updateFactory(data: FactoryForm, id: string): Promise<BaseResponse> {
    const response = await ajaxEngine().put(`/equipment/updateManufacturers/${id}`, data);
    return unwrap(response);
}

/**
 * 删除厂家
 * @param id string
 */
export async function deleteFactory(id: string): Promise<BaseResponse> {
    const response = await ajaxEngine().delete(`/equipment/deleteManufacturers/${id}`);
    return unwrap(response);
}

/**
 * 导出厂家模板
 */
export async function downloadFactoryTemplate() {
    return downloadFile(`/equipment/exportManufacturersTemplate`);
}
/**
 * 导出通讯协议数据
 */
export async function downloadFactory(park: string, query: any) {
    return downloadFile(`/equipment/exportManufacturers/${park}?${qs.stringify(query)}`);
}
/**
 * 上传通讯协议
 * @param park 园区id
 * @param file 文件对象
 * @param onProgress 进度监听
 */
export async function uploadFactory(
    park: string,
    file: File,
    onProgress?: (percent: number) => void
): Promise<BaseResponse & { errors: UploadExcelError[] | null }> {
    const response = await ajaxEngine().postForm(
        `/equipment/uploadCard/${park}`,
        { data: file },
        { onUploadProgress: (e: ProgressEvent) => onProgress?.(e.loaded / e.total) }
    );
    return unwrap(response);
}

/**
 * 获取电表设置列表
 * @param query MeterSettingListQuery
 */
export async function getMeterSettingList(query: MeterSettingListQuery): Promise<BaseResponse & Pageable & { data: MeterSettingListItem[] }> {
    const response = await ajaxEngine().get(`/equipment/getMeterSettingList?${qs.stringify(query)}`, {});
    return unwrap(response);
}
/**
 * 绑定网关
 * @param data BindProtocolForm
 */
export async function bindProtocol(data: BindProtocolForm): Promise<BaseResponse> {
    const response = await ajaxEngine().post(`/equipment/bindProtocol`, data);
    return unwrap(response);
}
/**
 * 新增电表设置
 * @param data BindProtocolForm
 */
export async function createMeterSetting(pid: string, data: MeterSettingForm): Promise<BaseResponse> {
    const response = await ajaxEngine().post(`/meter/${pid}`, data);
    return unwrap(response);
}
/**
 * 编辑电表设置
 * @param data BindProtocolForm
 */
export async function updateMeterSetting(pid: string, id: string, data: MeterSettingForm): Promise<BaseResponse> {
    const response = await ajaxEngine().put(`/meter/${pid}/${id}`, data);
    return unwrap(response);
}
/**
 * 绑定卡
 * @param data BindProtocolForm
 */
export async function bindCard(data: BindCardForm): Promise<BaseResponse> {
    const response = await ajaxEngine().post(`/equipment/bindCard`, data);
    return unwrap(response);
}
/**
 * 批量设置电表参数
 * @param data BindProtocolForm
 */
export async function batchSetMeterParams(data: BatchParamsForm): Promise<BaseResponse> {
    const response = await ajaxEngine().put(`/equipment/setMeterParams`, data);
    return unwrap(response);
}

/**
 * 获取电表操作列表
 * @param query MeterSettingListQuery
 */
export async function getMeterOperateList(query: MeterOperateListQuery): Promise<BaseResponse & Pageable & { data: MeterOperateListItem[] }> {
    const response = await ajaxEngine().get(`/equipment/getOperateMeterList?${qs.stringify(query)}`, {});
    return unwrap(response);
}

/**
 * 批量拉，合闸
 * @param data BindProtocolForm
 */
export async function batchSwtich(data: BatchSwitchForm): Promise<BaseResponse & { data: BatchMeterResult[] }> {
    const response = await ajaxEngine().put(`/equipment/batchSwtich`, data);
    return unwrap(response);
}

/**
 * 批量下发预警短信
 * @param data BindProtocolForm
 */
export async function batchSendMessage(data: {ids: Key[]}): Promise<BaseResponse & { data: BatchMeterResult[] }> {
    const response = await ajaxEngine().put(`/equipment/batchSendMessage`, data);
    return unwrap(response);    
}

/**
 * 批量设置强控和预付费
 * @param data BindProtocolForm
 */
export async function batchMode(data: BatchModeForm): Promise<BaseResponse  & { data: BatchMeterResult[] }> {
    const response = await ajaxEngine().put(`/equipment/batchSetMode`, data);
    return unwrap(response);
}

/**
 * 批量设置告警
 * @param data BindProtocolForm
 */
export async function batchSetWarning(data: BatchWarningForm): Promise<BaseResponse  & { data: BatchMeterResult[] }> {
    const response = await ajaxEngine().put(`/equipment/batchSetWarning`, data);
    return unwrap(response);
}

/**
 * 批量故障申报
 * @param data BindProtocolForm
 */
export async function batchSetTrouble(data: BatchTroubleForm): Promise<BaseResponse  & { data: BatchMeterResult[] }> {
    const response = await ajaxEngine().put(`/equipment/setTrouble`, data);
    return unwrap(response);
}


/**
 * 获取套表列表
 * @param query MeterSettingListQuery
 */
export async function getNestedMeterList(park: string, query: { page: number }): Promise<BaseResponse & Pageable & { data: NestedMeterListItem[] }> {
    const response = await ajaxEngine().get(`/equipment/getNestedMeterList/${park}?${qs.stringify(query)}`, {});
    return unwrap(response);
}

/**
 * 新增套表
 * @param data BindProtocolForm
 */
export async function addNestedMeter(data: NestedMeterForm): Promise<BaseResponse> {
    const response = await ajaxEngine().post(`/equipment/addNestedMeter`, data);
    return unwrap(response);
}
/**
 * 设置表停，启用
 * @param data BindProtocolForm
 */
export async function changeMeterEnabled(data: ChangeMeterEnabledForm): Promise<BaseResponse> {
    const response = await ajaxEngine().put(`/equipment/changeMeterEnabled`, data);
    return unwrap(response);
}
/**
 * 新增套表
 * @param data BindProtocolForm
 */
export async function deleteNestedMeter(id: string): Promise<BaseResponse> {
    const response = await ajaxEngine().delete(`/equipment/deleteNestedMeter/${id}`);
    return unwrap(response);
}

/**
 * 编辑套表
 * @param data BindProtocolForm
 */
export async function updateNestedMeter(id: string, data: NestedMeterForm): Promise<BaseResponse> {
    const response = await ajaxEngine().put(`/equipment/updateNestedMeter/${id}`, data);
    return unwrap(response);
}
