import { ajaxEngine } from "./axios_instance"
import {unwrap} from "@u/asyncs";
import qs from "qs";
import {BaseResponse} from "@/shared/model-components";
import {ApproveListQuery, DisposeFlow, FlowDetail, FlowForm, FlowListItem} from "@/shared/model-flow";
import {BaseUserInfo} from "@/shared/model-user";

/**
 * 获取审批流程列表
 * */
export async function getFlowList() : Promise<BaseResponse & { data: FlowListItem[], total: number }> {
  const response = await ajaxEngine().get(`/flow/list`)
  return unwrap(response)
}

/**
 * 新建审批流程
 * */
export async function createFlow(data: FlowForm) : Promise<BaseResponse> {
  const response = await ajaxEngine().post(`/flow/create`, data)
  return unwrap(response)
}
/**
 * 获取审批流程列表
 * */
export async function getApproveList(data: ApproveListQuery) : Promise<BaseResponse & { data: FlowListItem[], total: number }> {
  const response = await ajaxEngine().get(`/flow/getDisposeList?${qs.stringify(data)}`)
  return unwrap(response)
}
/**
 * 更新审批流程
 * */
export async function updateFlow(id: string, data: FlowForm) : Promise<BaseResponse> {
  const response = await ajaxEngine().put(`/flow/${id}/update`, data)
  return unwrap(response)
}
/**
 * 删除审批流程
 * */
export async function deleteFlow(id: string) : Promise<BaseResponse> {
  const response = await ajaxEngine().delete(`/flow/${id}/delete`)
  return unwrap(response)
}

/**
 * 获取可审核的所有用户
 * */
export async function getApproveUserList() : Promise<BaseResponse & { data: BaseUserInfo[] }> {
  const response = await ajaxEngine().get(`/flow/allUser`)
  return unwrap(response)
}
/**
 * 处理当前申请
 * */
export async function disposeFlow(id: string, data: DisposeFlow) : Promise<BaseResponse> {
  const response = await ajaxEngine().put(`/flow/${id}/dispose`, data)
  return unwrap(response)
}
/**
 * 删除文件
 * */
export async function deleteFile(url: string) : Promise<BaseResponse> {
  const response = await ajaxEngine().delete(`/file/delete?path=${url}`)
  return unwrap(response)
}

/**
 * 获取当前审批的详情
 * */
export async function getApproveDetail(id: string) : Promise<BaseResponse & { data: FlowDetail }> {
  const response = await ajaxEngine().get(`/flow/${id}/detail`)
  return unwrap(response)
}

