import { BaseResponse } from '@/shared/model-components';
import { UserSession } from '@/shared/model-user';
import { unwrap } from '@u/asyncs';
import { ajaxEngine } from './axios_instance';
import { privilege } from '@/shared/model-sonaccount';

/**
 * 用户登录请求的响应结构。
 */
export interface LoginResponse extends BaseResponse {
  /**
   * 用户是否需要重置密码。
   */
  needReset: boolean;
  /**
   * 服务端返回的用户会话信息。
   */
  session?: UserSession | null;
  /** 角色 */
  privileges?: privilege[],
  /** 权限列表 */
  roles?: []
}

/**
 * 执行用户在页面上发起的登录请求。
 * @param username 用户名。
 * @param password 用户的登录密码或重置用验证码。
 * @param type 用户所使用的登录表单类型，也算是用户类型。0：企业表单，1：监管及运维表单。
 * @returns 服务端返回的登录请求响应。
 */
export async function login(
  username: string,
  password: string,
  type: number
): Promise<LoginResponse> {
  const response = await ajaxEngine(true).post<LoginResponse>(`/login`, {
    uname: username,
    upass: password,
    type
  });
  return unwrap(response);
}

/**
 * 执行用户或系统发起的登出请求。
 * @returns 服务端返回的登出请求处理结果。
 */
export async function logout(): Promise<BaseResponse> {
  const response = await ajaxEngine().delete<BaseResponse>(`/login`);
  return unwrap(response);
}
