import type { BaseResponse, Pageable } from '@/shared/model-components';
import { ajaxEngine } from '@q/axios_instance';
import { unwrap } from '@u/asyncs';
import qs from 'qs';
import {
  AccountingStatement,
  DefaultQuery,
  ElectricDetailStatement,
  ElectricStatement, InvoiceStatement,
  RechargeStatement, TenementStatement
} from '@/shared/model-statement';
import {downloadFile} from "@q/common";

/**
 * 查询充值记录报表
 * @param park 园区id
 * @param page 页码
 * @param startDate 开始时间
 * @param endDate 结束时间
 */
export async function rechargeStatement({
                                       page,
                                       startDate,
                                       endDate,
                                       park,

                                     }: DefaultQuery): Promise<BaseResponse & Pageable & { data: RechargeStatement[] }> {
  const response = await ajaxEngine().get(`/statement/recharge?${qs.stringify({
    page,
    startDate,
    endDate,
    park,
  })}`);
  return unwrap(response);
}
/**
 * 查询用电情况报表
 * @param park 园区id
 * @param page 页码
 * @param startDate 开始时间
 * @param endDate 结束时间
 */
export async function electricStatement({
                                          page,
                                          startDate,
                                          endDate,
                                          park,

                                        }: DefaultQuery): Promise<BaseResponse & Pageable & { data: ElectricStatement[] }> {
  const response = await ajaxEngine().get(`/statement/electric?${qs.stringify({
    page,
    startDate,
    endDate,
    park,
  })}`);
  return unwrap(response);
}
/**
 * 查询用电详情报表
 * @param park 园区id
 * @param page 页码
 * @param startDate 开始时间
 * @param endDate 结束时间
 */
export async function electricDetailStatement({
                                          page,
                                          startDate,
                                          endDate,
                                          park,
                                        }: DefaultQuery): Promise<BaseResponse & Pageable & { data: ElectricDetailStatement[] }> {
  const response = await ajaxEngine().get(`/statement/electricDetail?${qs.stringify({
    page,
    startDate,
    endDate,
    park,
  })}`);
  return unwrap(response);
}
/**
 * 查询账务记录报表
 * @param park 园区id
 * @param page 页码
 * @param startDate 开始时间
 * @param endDate 结束时间
 */
export async function accountingStatement({
                                                page,
                                                startDate,
                                                endDate,
                                                park,
                                              }: DefaultQuery): Promise<BaseResponse & Pageable & { data: AccountingStatement[] }> {
  const response = await ajaxEngine().get(`/statement/accounting?${qs.stringify({
    page,
    startDate,
    endDate,
    park,
  })}`);
  return unwrap(response);
}

/**
 * 查询发票记录报表
 * @param park 园区id
 * @param page 页码
 * @param startDate 开始时间
 * @param endDate 结束时间
 */
export async function invoiceStatement({
                                            page,
                                            startDate,
                                            endDate,
                                            park,
                                          }: DefaultQuery): Promise<BaseResponse & Pageable & { data: InvoiceStatement[] }> {
  const response = await ajaxEngine().get(`/statement/invoice?${qs.stringify({
    page,
    startDate,
    endDate,
    park,
  })}`);
  return unwrap(response);
}

/**
 * 查询商户记录报表
 * @param park 园区id
 * @param page 页码
 * @param startDate 开始时间
 * @param endDate 结束时间
 */
export async function tenementStatement({
                                         page,
                                         startDate,
                                         endDate,
                                         park,
                                       }: DefaultQuery): Promise<BaseResponse & Pageable & { data: TenementStatement[] }> {
  const response = await ajaxEngine().get(`/statement/tenement?${qs.stringify({
    page,
    startDate,
    endDate,
    park,
  })}`);
  return unwrap(response);
}


/**
 * 报表导出
 * @param park 报表Id
 * @param type 类型
 */
export function downloadStatement(park: string, type: number) {
  downloadFile(`/statement/export?park=${park}&type=${type}`).then(() => {});
}
