// noinspection JSNonASCIINames

import { Key } from "react";

export enum Operator {
    "移动",
    "联通",
    "电信",
}

export enum MeterStatus {
    "在库",
    "运行",
    "待校",
    "故障",
}

export enum MeterLevel {
    "总表",
    "主表",
    "从表",
}

export enum CommunicationProtocol {
    "TcpServer模式",
    "TcpClient模式",
    "NB网关模式",
}

export enum Collector {
    "低压采集器",
    "采集终端",
}

export enum MessageWay {
    "载波",
    "无线",
    "4G",
}

export enum Bps {
    "1200bps",
    "2400bps",
    "4800bps",
    "9600bps",
    "19200bps",
    "38400bps",
}

export enum SN {
    "TcpClient模式",
    "NB网关模式",
}

/**
 * 通讯协议
 * */
export interface ProtocolItem {
    /**
     * 波特率，0- 1200bps ， 1- 2400bps 2- 4800bps， 3- 9600bps， 4- 19200bps ， 5- 38400bps
     */
    bps: number;
    /**
     * IP地址
     */
    harvester_ip: string;
    /**
     * 采集器类型，0：低压采集器 - 1：采集终端
     */
    harvester_type: number;
    /**
     * imei
     */
    imei: string;
    /**
     * 端口
     */
    port: number;
    /**
     * 通讯协议，0-TcpServer模式, 1-TcpClient模式, 2-NB网关模式
     */
    protocol: number;
    /**
     * 网关SN
     */
    sn: string;
    [property: string]: any;
}

/**
 * 卡管理
 */
export interface CardItem {
    /**
     * 运营商，- 0：移动 - 1：联通 - 2：电信
     */
    operator: number;
    /**
     * 手机卡号
     */
    sim_number: string;
    /**
     * SIN码
     */
    sin: string;
    /**
     * 状态，- 0：在库 - 1：运行 - 2：待校验 - 3：故障
     */
    type: number;
    [property: string]: any;
}

/**
 * 厂家
 */
export interface CommunicationItem {
    /**
     * 通讯方式，- 0：载波 - 1：无线 - 2：4  G
     */
    communication_mode: number;
    /**
     * 厂家名称
     */
    manufacturers_name: string;
    [property: string]: any;
}
export interface FactoryListItem extends CommunicationItem {
    id: string,
    created_at: string,
}

export interface FactoryForm extends CommunicationItem {
    id: string,
    created_at: string,
}

/** 卡管理列表 */
export interface CardListItem extends CardItem {
    created_at: string;
    delete_at: string;
    id: string;
    last_modify_at: string;
}

/** 卡编辑表单 */
export interface CardForm {
    /**
     * 运营商，- 0：移动 - 1：联通 - 2：电信
     */
    operator: number;
    /**
     * 园区id
     */
    // park?: string;
    /**
     * 手机卡号
     */
    sim_number: string;
    /**
     * SIN码
     */
    sin: string;
    [property: string]: any;
}

export interface CardListQuery {
    /**
     * 结束时间
     */
    endDate?: string;
    page?: number;
    /**
     * 园区id
     */
    // park: string;
    /**
     * 手机号
     */
    phone?: string;
    /**
     * sin卡号
     */
    sinCard?: string;
    keyword?: string;
    /**
     * 开始时间
     */
    startDate?: string;
    [property: string]: any;
}
/** 通讯协议列表 */
export interface ProtocolListItem extends ProtocolItem {
    id: string
}
/** 通讯协议搜索表单 */
export interface ProtocolListQuery {
    /**
     * 关键字
     */
    keyword?: string;
    page: number;
    /**
     * 园区id
     */
    // park: string;
    /**
     * 通讯协议   0-TcpServer模式, 1-TcpClient模式, 2-NB网关模式
     */
    protocol?: number;
    [property: string]: any;
}
/** 通讯协议表单 */
export interface ProtocolForm {
    /**
     * 波特率，0- 1200bps ， 1- 2400bps 2- 4800bps， 3- 9600bps， 4- 19200bps ， 5- 38400bps
     */
    bps: number;
    /**
     * IP地址
     */
    harvester_ip: string;
    /**
     * 采集器类型，0：低压采集器 - 1：采集终端
     */
    harvester_type: number;
    /**
     * imei
     */
    imei: string;
    /**
     * 园区id
     */
    // park: string;
    /**
     * 端口
     */
    port: number;
    /**
     * 通讯协议，0-TcpServer模式, 1-TcpClient模式, 2-NB网关模式
     */
    protocol: number;
    /**
     * 网关SN
     */
    sn: string;
    [property: string]: any;
}
/** 厂家列表搜索 */
export interface FactoryListQuery {
    /**
     * 名字
     */
    name?: string;
    /**
     * 页码
     */
    page: number;
    /**
     * 园区id
     */
    // park: string;
    /**
     * 通讯方式   - 0：载波 - 1：无线 - 2：4  G
     */
    way?: number;
    [property: string]: any;
}

/** 表计设置列表 */
export interface MeterSettingListItem {
    /**
     * 表计地址
     */
    address: string;
    /**
     * 建筑
     */
    building: string;
    /**
     * 表号
     */
    code: string;
    /**
     * 启用状态
     */
    enabled: boolean;
    /**
     * 楼层
     */
    floor: string;
    id: string;
    /**
     * 抄表序号
     */
    index: string;
    /**
     * 表级别，（- 0：总表 - 1：主表 - 2：从表）
     */
    level: number;
    /**
     * 电表箱
     */
    meterBox: string;
    boxId: string,
    boxAddress: string,
    /**
     * 手机卡号
     */
    phone: string;
    /**
     * 通讯协议
     */
    protocol: string;
    /**
     * 倍率
     */
    rate: string;
    /**
     * 状态，- 0：在库 - 1：运行 - 2：待校验 - 3：故障
     */
    status: number;
    /**
     * 类型，（- 0：商户表- 1：园区表- 2：公摊表）
     */
    type: number;
    [property: string]: any;
}


export interface MeterSettingListQuery {
    /**
     * 表号
     */
    code?: string;
    /**
     * 是否启用
     */
    enabled?: boolean;
    /**
     * 表级别（- 0：总表 - 1：主表 - 2：从表）
     */
    level?: number;
    /**
     * 状态
     * - 0：在库
     * - 1：运行
     * - 2：待校验
     * - 3：故障
     */
    status?: number;
    /**
     * 类型（- 0：商户表- 1：园区表- 2：公摊表）
     */
    type?: number;
    keyword?:string;
    [property: string]: any;
}

export interface BindProtocolForm {
    /**
     * 表计code列表
     */
    ids: string[];

    protocol: string;

    [property: string]: any;
}


export interface BindCardForm {
    /**
     * 卡号id
     */
    cardId: string;
    /**
     * 表号
     */
    codeId: string;
    [property: string]: any;
}


export interface MeterOperateListQuery {
    /**
     * 表号
     */
    code?: string;
    /**
     * 园区
     */
    park?: string;
    /**
     * 当前状态，（0-告警1，1-告警2，2-强制模式，3-预付费模式，4-拉闸，5-合闸，6-失联，7-欠费，8-开户，9-未开户，10-正常）
     */
    status?: number;
    /**
     * 商户id
     */
    tenement?: string;
    /**
     * 0：商户表计，1：园区表计，2：公摊表计
     */
    type?: number;
    [property: string]: any;
}


export interface MeterOperateListItem {
    /**
     * 地址
     */
    address: string;
    /**
     * 电表总量
     */
    amount: number;
    /**
     * 是否可连接
     */
    canConnect: boolean;
    /**
     * 表号
     */
    code: string;
    /**
     * 是否开户
     */
    isOpen: boolean;
    /**
     * 0-预付费，1-强控
     */
    mode: number;
    /**
     * 剩余金额
     */
    money: number;
    /**
     * 合闸状态，0-合闸，1-拉闸
     */
    onPosition: number;
    /**
     * 实时功率
     */
    realTimePower: string;
    /**
     * 采集时间
     */
    time: string;
    /**
     * 表计类型，0：商户表计，1：园区表计，2：公摊表计
     */
    type: number;
    /**
     * 告警1
     */
    warning1: number;
    /**
     * 告警2
     */
    warning2: string;
    id: string;
    [property: string]: any;
}

export interface BatchSwitchForm {
    /**
     * 表号id列表
     */
    ids: Key[];
    /**
     * 0-合闸，1-拉闸
     */
    status: number;
    [property: string]: any;
}


/**
 * 电表批量操作结果
 */
export interface BatchMeterResult {
    /**
     * 表号
     */
    code: string;
    /**
     * 表id
     */
    id: string;
    address: string,
    /**
     * 是否操作成功
     */
    succcess: boolean;
    [property: string]: any;
}


export interface BatchModeForm {
    /**
     * 表号id列表
     */
    ids: Key[];
    /**
     * 0-预付费，1-强控
     */
    mode: number;
    [property: string]: any;
}

export interface BatchWarningForm {
    /**
     * 表号id列表
     */
    ids: Key[];
    /**
     * 告警1
     */
    warning1: number;
    /**
     * 告警2
     */
    warning2: number;
    [property: string]: any;
}

export interface BatchTroubleForm {
    /**
     * 表计id列表
     */
    ids: string[];
    /**
     * 类型，0-故障申报，1-故障确认，2-恢复正常
     */
    type: number;
    [property: string]: any;
}

export interface BatchParamsForm {
    /**
     * 赊欠
     */
    credit: number;
    /**
     * 尖
     */
    critical: number;
    /**
     * 平
     */
    flat: number;
    /**
     * 峰
     */
    peak: number;
    /**
     * 谷
     */
    valley: number;
    /**
     * 告警1
     */
    warning1: number;
    /**
     * 告警2
     */
    warning2: number;
    ids: string[],
    [property: string]: any;
}

export interface NestedMeterListItem {
    /**
     * 主表地址
     */
    address: string;
    childrenCodes: NestedMeterListItemChild[];
    /**
     * 主表编号
     */
    code: string;
    id: string;
    codeId: string,
    [property: string]: any;
}

export interface NestedMeterListItemChild {
    /**
     * 套表地址
     */
    address: string;
    /**
     * 套表表号
     */
    code: string;
    id: string,
    [property: string]: any;
}

export interface NestedMeterForm {
    /**
     * 从表
     */
    childrenCode: string[];
    /**
     * 主表号
     */
    mainCode: string;
    park?: string;
    [property: string]: any;
}

export interface MeterSettingForm {
    /**
     * 表址
     */
    address: null | string;
    /**
     * 所辖面积
     */
    area: null | string;
    /**
     * 电表箱
     */
    boxId: string;
    /**
     * 所在建筑ID
     */
    building: null | string;
    /**
     * 表计表号
     */
    code: string;
    /**
     * 表级别， 0：总表 - 1：主表 - 2：从表
     */
    level: number;
    /**
     * 所在建筑楼层
     */
    onFloor: null | string;
    /**
     * 倍率
     */
    ratio: string;
    /**
     * 表计类型，0：商户表计，1：园区表计，2：公摊表计
     */
    type: number;
    [property: string]: any;
}

export interface ChangeMeterEnabledForm {
    /**
     * 是否启用
     */
    enabled: boolean;
    /**
     * 表id
     */
    ids: Key[];
    /**
     * 停用时间
     */
    time?: string;
    [property: string]: any;
}
