import { Meter04KvInfo, TenementInfo } from './model-park'
import { ChargeInfo, SyncStatus } from './model-charge'
import { InvoiceInfo } from './model-invoice'

// 账务列表每一项
export interface Record {
    /** 账务记录条目ID */
    id: string,
    /** 发生时间 */
    occurredAt?: string,
    /** 账目类型 */
    type?: string,
    /** 收入 */
    income?: number,
    /**支出 */
    expenditure?: number,
    /** 余额 */
    balance?: number,
    /** 发生方式 */
    transfer?: string,
    /** 账目元信息 */
    meta?: Meta,
    /** 操作员名称 */
    operator?: string,
    /** 审核员ID */
    auditor?: string,
    /** 审核员名称 */
    auditorName?: string,
    /** 审核时间 */
    auditedAt?: string,
    tenement?: string,
    // 账目元信息
    topUpMeta?: TopUpMeta,
    /** 金额 */
    money: number,
    /** 同步状态 */
    syncStatus: SyncStatus
}

interface TopUpMeta {
    /** 备注 */
    remark?: string,
    /** 附加操作 */
    appendOperation?: string,
    /** 账目方向 */
    direction?: string,
    /** 账目金额 */
    amount?: number,
    /** 附加操作记录表号 */
    code?: string,
    /** 回滚id */
    sid?: string,
    /** 表号 */
    meters: string [],
    /** 凭证号 */
    vouchNo: string,
}

// 账目元信息
export interface Meta {
    /** 关联表计信息 */
    meter?: Meter,
    /** 关联重置记录ID */
    chargeRecord?: ChargeInfo | null,
    /** 关联重置写表任务ID */
    chargeTask?: ChargeTask | null,
    /** 关联商户信息 */
    tenement?: TenementInfo,
    /** 已开具发票记录 */
    invoice?: InvoiceInfo
    /** 对应code */
    code ?: string
    /** 备注 */
    remark?: string
    direction?: number
    appendOperation: number
}

// 关联表计信息
export interface Meter extends Meter04KvInfo {
    /** 表计表显倍率 */
    displayRatio: string,
}

// 关联重置写表任务ID
export interface ChargeTask {
    /** 同步任务ID */
    id: string,
    /** 归属企业ID */
    userId: string,
    /** 归属园区ID */
    parkId: string,
    /** 任务简报 */
    briefing: string,
    /** 计划执行时间 */
    scheduleAt: string,
    /** 上次执行时间 */
    lastDispatchedAt: string | null,
    /** 执行耗时 单位：毫秒 */
    executionCost: number,
    /** 尝试次数 */
    attempts: number,
    /** 当前状态 */
    status: ChargeTaskStatus,
    /** 锁定状态 */
    lockDown: ChargeTaskLockDown,
    /** 任务元信息 */
    meta: ChargeTaskMeta,

}

export enum AccountDirection {
    in,
    out
}

export enum AppendOperate {
    '充值',
    '冲正',
    '退费',
    '电费发行',
    "结算"
}

export enum GenerateWay {

}

export enum ChargeTaskStatus {
    /** 队列中 */
    queue,
    /** 执行中 */
    execution,
    /** 成功 */
    success,
    fail,
    cancel
}

export enum ChargeTaskLockDown {
    /** 未锁定 */
    unlocked,
    /** 系统锁定 */
    systemLock,
    /** 人工锁定 */
    artificialLock
}

export interface ChargeTaskMeta {
    /** 任务目标 */
    objective: string,
    /** 表计编号 */
    meterCode: string,
    /** 远程平台代号 */
    imrs: string,
    /** 远程平台名称 */
    imrsName: string,
    /** 远程平台URL 如果是原生平台则采用自定义URL Scheme */
    imrsUrl: string,
    /** 最大重试次数 */
    maxRetries: number,
    /** 重试间隔算法 */
    intervalAlgorithm: IntervalAlgorithm,
    /** 重试基础间隔 */
    interval: string,
}

export enum IntervalAlgorithm {
    /** 指数退避 */
    /** 2倍线性间隔 */
    /** 3倍线性间隔 */
    /** 固定间隔 */
}


export interface Related {
    index?: number,
    /** 汇算记录ID */
    id: string,
    /** 汇算起始日期 */
    settlingStart: string,
    /** 汇算结束日期 */
    settlingEnd: string,
    /** 账务主体ID */
    tenement: string,
    /** 账务简称 */
    tenementName: string,
    /** 商户全称 */
    tenementFullName: string,
    /** 总收入 */
    totalIncome: number,
    /** 总支出 */
    totalExpenditure: number,
    /** 汇算期初余额 */
    initialBalance: number,
    /** 汇算余额 */
    balance: number,
    /** 汇算类型 */
    type: number,
}

export interface Overall {
    /** 汇算记录ID */
    id: string,
    /** 汇算起始日期 */
    settlingStart: string,
    /** 汇算结束日期 */
    settlingEnd: string,
    /** 账务主体ID */
    tenement: string,
    /** 账务主体名称 */
    tenementName: string,
    /** 总收入 */
    totalIncome: string,
    /** 总支出 */
    totalExpenditure: string,
    /** 汇算期初余额 */
    initialBalance: string,
    /** 汇算余额 */
    balance: string
}

interface EditAccountingDataMeta {
    remark?: string;
    appendOperation?: number;
    code?: string;
    direction?: number;
}

export interface EditAccountingData {
    /** 账目类型 */
    type: string,
    /** 转账类型 */
    paymentType: string,
    /** 发生金额 */
    amount: string,
    /** 账务条目发生时间 */
    occurredAt: string,
    /** 附属元信息 */
    // meta: string,
    meta: EditAccountingDataMeta,
    /** 账务条目主体ID */
    tenement: string,
    /** 园区id */
    parkId: string,
    /** 凭证号 */
    vouchNo: string,
}


// export interface CreateAccountingData extends UpdateAccountingData {

// }


export interface Settlement {
    /** 结算记录ID */
    id: string,
    /** 结算日期 */
    settledAt: string,
    /** 账务主体ID */
    tenement: string,
    /** 账务主体名称 */
    tenementName: string,
    /** 表计编号 */
    meterCode: string,
    /** 合计充值 */
    totalIncome: number,
    /** 合计消费 */
    totalExpenditure: number,
    /** 结算状态 */
    status: string,
    /** 清算余额 */
    balance: string,
    /** 操作员 */
    operator: string,
    /** 审核员 */
    auditor: string | null
}

// 支付类型
export enum AccountingType {
    '现金',
    '银行卡',
    '支付宝',
    '微信',
    '云闪付',
    '对公转账',
    "C端-微信"
}

// 发生方式
export enum HappenWay {
    '充值',
    '冲正',
    '电费',
    "退费",
  "初始化余额"
}

// 汇算类型
export enum SettleAccountType {
    '阶段汇算',
    '结算',
    '终算',
    '实时汇算'
}

export interface BalanceOverall {
    /** 商户全称 */
    tenementFullName: string,
    /** 商户简称 */
    tenementName: string,
    /** 商户电表数量 */
    metersCount: number,
    /** 商户汇算起始金额 */
    initialBalance: number,
    /** 商户已使用金额 */
    totalExpenditure: number,
    /** 商户充值总金额 */
    totalIncome: number,
    /** 余额 */
    balance: number,
}
