import { BasePublicityInfo } from '@/shared/model-publicity';

/**
 * 电费计算报表信息
 */
export type ReportInfo = BasePublicityInfo;

/**
 * 公示报表步骤状态
 */
export interface ReportSteps {
  /** 试计算步骤 */
  calculate: boolean;
  /** 预览报表步骤 */
  preview: boolean;
  /** 发布步骤 */
  publish: boolean;
  /** 户表抄表填写 */
  submeter: boolean;
  /** 园区总表填写状态 */
  summary: boolean;
  /** 待摊薄填报状态 */
  willDiluted: boolean;
}


/**
 * 公示记录已填写的总电量
 */
export interface ReportElectricSummary {
  /** 核算报表Id */
  reportId: string;
  /** 总消耗电度 */
  overall: Consumption;
  /** 总建筑面积 */
  area: string;
  /** 基本电费 */
  basicFee: string;
  pooledBasicFeeByAmount: string;
  pooledBasicFeeByArea: string;
  /** 调整电费 */
  adjustFee: string;
  pooledAdjustFeeByAmount: string;
  pooledAdjustFeeByArea: string;
  consumption: string;
  loss: string;
  lossRate: string;
}

/**
 * 填报电量计算返回结果
 */
export interface SummaryCaculateResult {
  /** 电度电费 */
  consumptionFee: null | string;
  /** 有功(尖峰)电价 */
  criticalPrice: null | string;
  /** 有功(平)电量 */
  flat: null | string;
  /** 有功(平)电费 */
  flatFee: null | string;
  /** 有功(平)电价 */
  flatPrice: null | string;
  /** 有功(总)电价，电费均价 */
  overallPrice: null | string;
  /** 有功(峰)电价 */
  peakPrice: null | string;
  /** 有功(谷)电价 */
  valleyPrice: null | string;
}

/**
 * 待摊薄费用信息
 */
export interface ReportMaintenance {
  /** 待摊薄记录ID */
  diluteId: string;
  /** 维护费数额，单位：元/月 */
  fee: string;
  /** 备注 */
  memo: null | string;
  /** 费用项目名称 */
  name: string;
  /** 所属报表ID */
  reportId: string;
  /** 来源预置ID，如果不为空，表示条目是导入得来 */
  sourceId: null | string;
}

/**
 * 抄表记录信息
 */
export interface MeterRecord {
  /** 户址 */
  address: null | string;
  /** 退补电量(尖峰) */
  adjustCritical: string;
  /** 退补电量(平) */
  adjustFlat: string;
  /** 退补电量 */
  adjustOverall: string;
  /** 退补电量(峰) */
  adjustPeak: string;
  /** 退补电量(谷) */
  adjustValley: string;
  /** 联系人名称 */
  contactName: null | string;
  /** 联系人电话 */
  contactPhone: null | string;
  /** 条目创建时间，时间格式为 yyyy-MM-dd HH:mm:ss */
  createdAt: string;
  /** 本期表底(尖峰) */
  currentPeriodCritical: null | string;
  /** 本期表底(平) */
  currentPeriodFlat: null | string;
  /** 本期表底(总) */
  currentPeriodOverall: string;
  /** 本期表底(峰) */
  currentPeriodPeak: null | string;
  /** 本期表底(谷) */
  currentPeriodValley: null | string;
  /** 用户名称 */
  customerName: null | string;
  /** 是否公用设备表计 */
  isPublicMeter: boolean;
  /** 条目最后修改时间，时间格式为 yyyy-MM-dd HH:mm:ss */
  lastModifiedAt: null | string;
  /** 上期表底(尖峰) */
  lastPeriodCritical: null | string;
  /** 上期表底(平) */
  lastPeriodFlat: null | string;
  /** 上期表底(总) */
  lastPeriodOverall: string;
  /** 上期表底(峰) */
  lastPeriodPeak: null | string;
  /** 上期表底(谷) */
  lastPeriodValley: null | string;
  /** 表计表号 */
  meterId: string;
  /** 表计倍率 */
  ratio: string;
  /** 抄表序号，使用抄表序号进行排序 */
  seq: number;
  /** 是否计入摊薄 */
  willDilute?: boolean;
}

/**
 * 已填写的报表电量电费信息
 */
export interface ReportFilled extends ReportMeterUnit {
  /** 调整电费 */
  adjustFee: string;
  /** 基本电费 */
  basicFee: string;
  /** 电度电费 */
  consumptionFee: null | string;
  /** 线损率 */
  authorizedLossRate: null | string;
  /** 光伏发电电量 */
  generateAmount?: number
}

/**
 * 核算报表中表计基本数据单元
 */
export interface ReportMeterUnit {
  /** 有功(尖峰)电量 */
  critical: Consumption;
  /** 有功(平)电量，计算得到的数值，不需要填写 */
  flat: Consumption;
  /** 有功(总)电量，总电量 */
  overall: Consumption;
  /** 有功(峰)电量 */
  peak: Consumption;
  /** 有功(谷)电量 */
  valley: Consumption;
}

/**
 * 电量消耗综合数据
 */
export interface Consumption {
  /** 电量 */
  amount: string;
  /** 电费 */
  fee: null | string;
  /** 电价 */
  price: null | string;
  /** 电费占比 */
  proportion: null | string;
}
