import { ParkInfo, TenementInfo } from "./model-park";
import { BaseUserInfo } from "./model-user";

/** 审批流程列表每一项 */
export interface FlowListItem {
  /** 设置人姓名 */
  setUserName: string;
  /** 设置时间 */
  setTime: string;
  /** 流程id */
  id: string;
  /** 流程名字 */
  name: string;
  /** 审核层级 */
  tier: number;
  /** 是否启用 */
  enable: boolean;
  /** 修改时间 */
  updateTime: string;
  /** 需要审批的用户们 */
  users: string[],
  /** 是否通知全体 */
  all: boolean,
  /** 类型 0-退费 */
  type: number,
  index?: number;
}

/** 新建审批流程表单数据 */
export interface  FlowForm {
  /** 流程id 0-退费 */
  type: 0
  /** 审核层级 */
  level: number;
  /** 审核用户列表 */
  users: string[];
  /** 是否通知所有人 */
  all: boolean,
  /** 是否启用 */
  enable: boolean
}

/** 获取当前提交审批列表 */
export interface ApproveListItem {
  /** 发起时间 */
  applyTime: string
  /** 发起人 */
  applyUserName: string
  /** 发起人id */
  applyUserID: string
  /** 类型   （0-退费申请） */
  type: number
  /** 操作状态 0-待处理，1-同意，2-拒绝 */
  operateStatus: number
  /** 流程状态   （1-处理中，2-已完成，3-已退回） */
  flowStatus: number
  /** 审批id */
  id: string,
  /** 商户 */
  tenement: TenementInfo,
  /** 园区 */
  park: ParkInfo,
}

/** 获取当前提交审批列表参数 */
export interface ApproveListQuery {
  /** 商户id */
  tenement?: string
  /** 操作类型（0-退费申请） */
  type?: number
  /** 流程状态（1-处理中，2-已完成，3-已退回） */
  status?: number
  /** 页码 */
  page?: number
}

interface FlowDetailList {
  /** 时间 */
  time: string,
  /** 操作人 */
  user: BaseUserInfo,
  /** 类型 0-已发起，1-同意，2-拒绝*/
  type: 0 | 1, 2,
  /** 审批意见 */
  reason: string,
  /** 操作内容 */
  content: string,
  index?: number,
}

/** 获取当前审批的详情 */
export interface FlowDetail {
  /** 商户全称 */
  fullName?: string
  /** 电表编号 */
  code?: string
  /** 账务余额 */
  balance?: number
  /** 退费金额 */
  amount?: number
  /** 上传附件 */
  fileList?: string[],
  /** 申请原因 */
  reason?: string,
  /**列表 */
  list?:FlowDetailList[];
  /** 商户 */
  tenement?: TenementInfo,
  /** 园区 */
  park?: ParkInfo,
}

export interface DisposeFlow {
  /** 审批意见 */
  content: string,
  /** 操作 0-不同意，1-同意 */
  status: 0 | 1,
}

export interface FlowSelectItem {
  label: string,
  value: number,
}

export const flowList: FlowSelectItem[] = [
  { label: "退费", value: 0 }
]

export const flowStatusList: FlowSelectItem[] = [
  { label: "处理中", value: 1 },
  { label: "已完成", value: 2 },
  { label: "已退费", value: 3 },
]

export const operateStatusList: FlowSelectItem[] = [
  { label: "待处理", value: 0 },
  { label: "同意", value: 1 },
  { label: "拒绝", value: 2 },
]