
/**
 * 票据信息
 */
export interface InvoiceInfo {
  id: string,
  /** 开票金额，即价税合计 */
  amount: string;
  /** 开票时间，记录时间，格式：yyyy-MM-dd HH:mm:ss */
  issuedAt: string;
  /** 发票号码 */
  no: string;
  /** 税率 */
  taxRate: string;
  /** 计税方式，0：核算电费含税，1：核算电费未税 */
  taxMethod: TaxMethod;
  /** 商户ID */
  tenement: string;
  /** 抬头 */
  title: InvoiceTitle;
  /** 发票类型 */
  type: string;
  /** 开始时间 */
  periodStart: string,
  /** 结束时间 */
  periodEnd: string,
  /** 用电量 */
  quantity: number,
  /** 核算周期 */
  periodTime: periodTime[],
}

interface periodTime {
  time: string,
  codes: string[],
}

export const enum TaxMethod {
  Including,
  Excluding
}

export const enum PacketType {
  watch,
  cycle,
}


/**
 * 发票抬头信息
 */
export interface InvoiceTitle {
  /** 开户账号 */
  account: null | string;
  /** 注册地址 */
  address: null | string;
  /** 开户行名称 */
  bank: null | string;
  /** 开票人 */
  name: string;
  /** 注册电话 */
  phone: null | string;
  /** 开票人社会统一信用代码 */
  usci: string;
}

/**
 * 发票详情
 */
export interface InvoiceDetail extends InvoiceInfo {
  /** 发票货物清单 */
  cargos: {
    /** 货物名称 */
    name: string;
    /** 单价 */
    price: string;
    /** 数量 */
    quantity: string;
    /** 税额 */
    tax: string;
    /** 税率 */
    taxRate: string;
    /** 价税合计 */
    total: string;
    /** 单位 */
    unit: string;
  }[];
  /** 概述信息 */
  covers: {
    /** 核算电费总额 */
    fee: string;
    /** 核算周期结束，格式：yyyy-MM-dd */
    periodEnd: string;
    /** 核算周期起始，格式：yyyy-MM-dd */
    periodStart: string;
    /** 报表ID */
    report: string;
    /** 表号 */
    code: string
  }[];
}

/**
 * 指定商户的未开票信息
 */
export interface UninvoicedRecord {
  /** 电费 */
  fee: string;
  /** 核算结束日期，格式：yyyy-MM-dd */
  periodEnd: string;
  /** 核算开始日期，格式：yyyy-MM-dd */
  periodStart: string;
  /** 电量 */
  quantity: string;
  /** 报表ID */
  report: string;
}

/**
 * 未开票的信息
*/
export interface UninvoiceData {
  /** 商户简称 */
  shortName: string;
  /** 商户全称 */
  fullName: string;
  /** 表计编号 */
  code: string;
  /** 单价 */
  price: number;
  /** 合计电费 */
  fee: number;
  /** 用电量 */
  quantity: number;
  /** 核算结束日期 */
  periodEnd: string;
  /** 核算开始日期 */
  periodStart: string;
  /** 报表ID */
  report: string;
  /** 商户id */
  tenementID: string;
  /** index */
  index: number;
}

export interface cover {
  code: string,
  tenementID: string,
  report: string,
}

export interface CreateInvoicePrimaryData {
  /** 商户id */
  tenementID: string
  /** 商户全称 */
  fullName: string;
  /** 报表id */
  // reportIDs: string[],
  /** 园区id */
  parkId: string,
  /** 表号列表 */
  covers: cover[]
}

