import {Meter04KvInfo, ParkInfo, TenementInfo} from "@/shared/model-park";
import {AccountingType, HappenWay} from "@/shared/model-accounting";
import {BaseUserInfo} from "@/shared/model-user";
/** 充值情况 **/
export interface RechargeStatement {
  /** 序号 **/
  index?: number,
  /** 园区 **/
  park: ParkInfo,
  /** 操作时间 **/
  operateTime?: number,
  /** 商户 **/
  tenement?: TenementInfo,
  /** 表计 **/
  meter?: Meter04KvInfo,
  /** 支付金额 **/
  money?: number,
  /** 付款方式 **/
  way?: AccountingType,
  /** 售电类型，0-充值，1-冲正，2-退费 **/
  type?: 0 | 1 | 2,
  /** 操作员 **/
  operateUser: BaseUserInfo
}
/** 用电情况 **/
export interface ElectricStatement {
  /** 序号 **/
  index?: number,
  /** 商户 **/
  tenement?: TenementInfo,
  /** 开始时间 **/
  startDate?: string,
  /** 结束时间 **/
  endDate?: string,
  /** 总电量 **/
  amount: number,
  /** 合计摊薄费用 **/
  pooledFee?: number,
  /** 合计公摊费用 **/
  publicFee?: number,
  /** 合计电费 **/
  amountFee?: number,
  /** 备注 **/
  remark: string,
}

/** 用电详细查询 **/
export interface ElectricDetailStatement {
  /** 序号 **/
  index?: number,
  /** 商户 **/
  tenement?: TenementInfo,
  /** 表计 **/
  meter?: Meter04KvInfo,
  /** 开始时间 **/
  startDate?: string,
  /** 结束时间 **/
  endDate?: string,
  /** 总电量 **/
  overallAmount: number,
  /** 电度电费 **/
  chargeFee?: number,
  /** 摊薄线损电量 **/
  lossAmount?: number,
  /** 摊薄调整电费 **/
  adjustPooled?: number,
  /** 公摊电费 **/
  publicPooled: number,
  /** 合计电费 **/
  finalAll: number,
  /** 备注 **/
  remark: string,
}

/** 账务记录查询 **/
export interface AccountingStatement {
  /** 序号 **/
  index?: number,
  /** 商户 **/
  tenement?: TenementInfo,
  /** 表计 **/
  meter?: Meter04KvInfo,
  /** 操作时间 **/
  operateDate?: string,
  /** 结束时间 **/
  type?: HappenWay,
  /** 上次余额 **/
  lastBalance: number,
  /** 金额 **/
  money?: number,
  /** 余额 **/
  balance?: number,
  /** 操作员 **/
  operateUser: BaseUserInfo
}
/** 发票记录 **/
export interface InvoiceStatement {
  /** 序号 **/
  index?: number,
  /** 商户 **/
  tenement?: TenementInfo,
  /** 表计 **/
  meter?: Meter04KvInfo,
  /** 初始金额 **/
  initMoney?: number,
  /** 累计充值金额 **/
  chargeMoney?: number,
  /** 已消耗金额 **/
  usedMoney: number,
  /** 已开票金额 **/
  invoiceMoney?: number,
  /** 开票后余额 **/
  invoiceBalance?: number,
  /** 备注 **/
  remark: string
}
/** 商户情况 **/
export interface TenementStatement extends TenementInfo{
  /** 序号 **/
  index?: number,
  /** 开票地址 **/
  invoiceAddress?: string,
}

export interface DefaultQuery {
  /** 开始时间 **/
  startDate?: string,
  /** 结束时间 **/
  endDate?: string,
  /** 页数 **/
  page?: number,
  /** 园区 **/
  park?: string,
}

/**
 * 报表类型
 */
// export const enum MeterType {
//   /** 充值查询 */
//   RechargeStatement,
//   /** 用电情况查询 */
//   ElectricStatement,
//   /** 用电详细查询 */
//   ElectricDetailStatement
// }

export enum StatementType {
  "充值查询",
  "用电情况查询",
  "用电详细查询",
  "账务记录",
  "发票记录",
  "商户情况"
}
