import { ParkInfo } from './model-park';

/**
 * 同步任务
 */
export interface SyncTask {
  /** 同步任务ID */
  id: string;
  /** 归属企业ID */
  userId: string;
  /** parkID */
  parkId: string;
  /** 企业用户ID */
  entId: string;
  /** 企业名称 */
  entName: string;
  /** 上次运行时间，格式：yyyy-MM-dd HH:mm:ss。最后同步时间，这个时间不保证同步任务一定成功 */
  lastDispatchedAt?: string;
  /** 上次运行结果，0：同步中，1：同步成功，2：同步失败，3：等待中，4：已暂停 */
  lastDispatchStatus?: SyncTaskStatus;
  /** 下次运行时间，格式：yyyy-MM-dd HH:mm:ss */
  nextDispatchAt?: string;
  /** 园区名称 */
  parkName: string;
  /** 任务ID */
  taskId?: string;
  /** 任务名称 */
  taskName?: string;
  /** 状态 (0:队列中，1:执行中，2:成功，3:失败，4:取消) */
  status: number
}

/**
 * 同步任务状态
 * 0：同步中，1：同步成功，2：同步失败，3：等待中，4：已暂停
 */
export const enum SyncTaskStatus {
  Synching,
  Success,
  Failure,
  Waiting,
  Pause
}

/**
 * 采集方式  0：自动+人工，1：自动，2：人工
 */
export const enum ReadingType {
  AutoManual,
  Auto,
  Manual
}

/**
 * 采集周期  0：每小时，1：每日，2：每周，3：每月
 */
export const enum ReadingInterval {
  Hour,
  Day,
  Week,
  Month
}

/**
 * 重试间隔方法  0：指数退避，1：2倍线性间隔，2：3倍线性间隔，3：固定间隔
 */
export const enum ReadingRetryAlgorithm {
  ExponentialBackOff,
  DoubleInterval,
  TripleInterval,
  FixedInterval
}

/**
 * 查看园区同步记录是否一致弹框列表
 */

export interface ParkSync {
  time: string,
  park: ParkInfo,
  ownNumber: number,
  targetNumber: number,
  isSame: number,
  id: string
}