/**
 * 用户发起登录请求时，服务端返回的会话信息。
 */
export interface UserSession {
  /** 当前会话所属的用户ID。 */
  uid: string;
  /** 当前会话的用户名称或姓名。 */
  name: string;
  /** 用户类型，0：企业，1：监管，2：运维 */
  type: UserType;
  /** 代表当前会话的令牌。 */
  token: string;
  /** 当前会话的过期时间。 */
  expiresAt: string;
  /** 菜单权限 */
  menu: string[]
}

/**
 * 用户类型
 */
export const enum UserType {
  /** 企业 */
  Enterprise,
  /** 监管 */
  Regulatory,
  /** 运维 */
  Maintainer
}

/**
 * 基本用户信息
 */
export interface BaseUserInfo {
  /** 用户联系人 */
  contact: null | string;
  /** 条目创建时间 */
  createdAt: string;
  /** 条目创建人，保存用户ID */
  createdBy: null | string;
  /** 条目是否启用 */
  enabled: boolean;
  /** 用户ID */
  id: string;
  /** 条目最后修改人，保存用户ID */
  lastModiedBy: null | string;
  /** 条目最后修改时间 */
  lastModifiedAt: null | string;
  /** 用户名称 */
  name: string;
  /** 用户联系人电话 */
  phone: null | string;
  /** 用户类型 */
  type: UserType;
  /** 用户账号 */
  username: string;
}

/**
 * 完整用户信息
 */
export interface UserInfo extends BaseUserInfo {
  /** 月服务费 */
  unitServiceFee: number | null;
  /** 服务过期时间，格式为 YYYY-MM-dd */
  serviceExpiration: string;
  /** 用户所在行政区划 */
  region: null | string;
  /** 用户地址 */
  address: null | string;
  /** 用户名称的拼音缩写 */
  abbr: null | string;
}
