import { AxiosResponse } from 'axios';
import { lt, not } from 'ramda';
import { BaseResponse } from '@/shared/model-components';
import { alertError } from '.';

/**
 * 对访问服务端产生的响应体进行解包处理，对于失败的访问抛出相应错误。
 * @param response Axios访问服务端产生的访问响应。
 * @returns 解包以后所需要的服务端返回的数据。
 */
export function unwrap<T extends BaseResponse>(response: AxiosResponse<T>): T {
  if (!response) {
    alertError('服务异常，请稍后重试')
    return null
  }
  if (not(lt(response.status, 300))) {
    // throw new NetworkError(response.status, response.data?.message || response.statusText);
  }
  return response.data;
}

/**
 * 服务端响应是否正常
 * @param result 响应结构
 */
export function isCorrectResult(result: BaseResponse) {
  return lt(result.code, 300);
}
