import {message} from "antd";

export const alertError = (msg: string) => {
    void message.error(msg)
}

export const alertSuccess = (msg: string) => {
  void message.success(msg)
}

export const alertInfo = (msg: string) => {
  void message.info(msg)
}

export const renderEmptyData = (data: any, suffix = '') => {
  if (data == null || data === '') {
    return "-"
  }
  return `${data}${suffix}`
}

// 节流函数
// eslint-disable-next-line @typescript-eslint/ban-types
export function throttle(fn: Function, delay: number) {
  let flag = true;
  return function() {
    if(!flag) return;
    flag = false;
    setTimeout(() => {
      // eslint-disable-next-line prefer-rest-params
      fn.apply(this, arguments);
      flag = true;
    }, delay)
  }
}

// 获取列表中序号
export function getIndex(page: number, index: number) : string {
  return `${(page - 1) * 20 + Number(index) + 1}`
}

interface Response {
  code: number,
  data: string,
  message: string,
}
interface FileList {
  crossOrigin: 'anonymous' | 'use-credentials' | '',
  uid: string,
  name: string,
  status: 'done' | 'uploading' | 'error' | 'removed',
  thumbUrl?: string
  url: string,
  response: Response
}

// 获取文件列表
export function getFileList(files: string[]): FileList[] {
  return files.map((item, index) => {
    const filename = item.slice(item.lastIndexOf('/') + 1)
    return {
      crossOrigin: 'anonymous',
      uid: `${Date.now() + index}`,
      name: filename,
      status: 'done',
      // response: '{"status": "success"}',
      response: { code: 0, message: '', data: item },
      url: item,
    }
  })
}

// 获取上传接口的文件列表
export function getFetchFileList(files: FileList[]) : string[] {
  return files.filter(item => item.status === "done").map(item => {
    return item?.response?.data
  })
}