//@ts-nocheck
import { lazy } from 'react';

/**
 * 惰性加载React组件工具函数。
 * @param loader 异步加载函数
 * @returns 经过异步惰性加载的组件。
 */
export const lazyLoad = <T, U extends keyof T>(loader: (x?: string) => Promise<T>) =>
  new Proxy({} as unknown as T, {
    get: (target, componentName: string | symbol) => {
      if (typeof componentName === 'string') {
        return lazy(() =>
          loader(componentName).then(x => ({
            default: x[componentName as U] as any as React.ComponentType<any>
          }))
        );
      }
    }
  });
